// controllers/projectEquipmentController.js

const ProjectEquipment = require('../models/ProjectEquipment');

/**
 * สร้างข้อมูล ProjectEquipment ใหม่ (Create)
 */
exports.createProjectEquipment = async (req, res) => {
    try {
        // ข้อมูลจาก body เช่น { project_id, equipment_id, quantity_in_project }
        const { project_id, equipment_id, quantity_in_project } = req.body;

        const newPE = await ProjectEquipment.create({
            project_id,
            equipment_id,
            quantity_in_project
        });

        return res.status(201).json({
            message: 'ProjectEquipment created successfully',
            projectEquipment: newPE
        });
    } catch (error) {
        console.error(error);
        return res.status(500).json({ error: error.message });
    }
};

/**
 * ดึงข้อมูล ProjectEquipments ทั้งหมด (Read All)
 */
exports.getAllProjectEquipments = async (req, res) => {
    try {
        const pes = await ProjectEquipment.findAll();
        return res.status(200).json(pes);
    } catch (error) {
        console.error(error);
        return res.status(500).json({ error: error.message });
    }
};

/**
 * ดึงข้อมูล ProjectEquipment ตาม pe_id (Read One)
 */
exports.getProjectEquipmentById = async (req, res) => {
    try {
        const { id } = req.params;  // pe_id
        const pe = await ProjectEquipment.findByPk(id);

        if (!pe) {
            return res.status(404).json({ error: 'ProjectEquipment not found' });
        }
        return res.status(200).json(pe);
    } catch (error) {
        console.error(error);
        return res.status(500).json({ error: error.message });
    }
};

/**
 * อัปเดตข้อมูล ProjectEquipment (Update)
 */
exports.updateProjectEquipment = async (req, res) => {
    try {
        // ดึง pe_id จากพารามิเตอร์ URL
        const { id } = req.params;

        // สมมติเรารับข้อมูลใหม่มาจาก req.body
        const { project_id, equipment_id, quantity_in_project } = req.body;

        // ขั้นตอนที่ 1: ค้นหา ProjectEquipment ด้วย pe_id
        const pe = await ProjectEquipment.findByPk(id);

        if (!pe) {
            // ถ้าไม่พบ record ที่ pe_id ตรงนี้ ให้ส่ง 404 กลับ
            return res.status(404).json({ error: 'ProjectEquipment not found' });
        }

        // ขั้นตอนที่ 2: อัปเดตค่าตามฟิลด์ที่อนุญาต
        // ตัวอย่างอัปเดต project_id, equipment_id, quantity_in_project
        // (ปรับตามโครงสร้างจริงของคุณ)
        await pe.update({
            project_id,
            equipment_id,
            quantity_in_project
        });

        // ดึงค่าที่เพิ่งอัปเดต (pe จะอัปเดตในตัวแล้ว แต่ถ้าอยากเพิ่มความชัดเจน ก็ findOne ซ้ำได้)
        // const updatedPE = await ProjectEquipment.findByPk(id);

        return res.status(200).json({
            message: 'ProjectEquipment updated successfully',
            projectEquipment: pe // หรือ updatedPE
        });
    } catch (error) {
        console.error(error);
        return res.status(500).json({ error: error.message });
    }
};

/**
 * ลบข้อมูล ProjectEquipment (Delete)
 */
exports.deleteProjectEquipment = async (req, res) => {
    try {
        const { id } = req.params;
        const rowsDeleted = await ProjectEquipment.destroy({ where: { pe_id: id } });

        if (!rowsDeleted) {
            return res.status(404).json({ error: 'ProjectEquipment not found' });
        }

        return res.status(200).json({ message: 'ProjectEquipment deleted successfully' });
    } catch (error) {
        console.error(error);
        return res.status(500).json({ error: error.message });
    }
};
