import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { environment } from 'src/environments/environment';
import { EquipmentModel } from '../models/equipments.model';
import { map, tap, switchMap, filter, reduce } from "rxjs/operators";

@Injectable({
  providedIn: 'root'
})
export class EquipmentService {


 apiBaseUrl = environment.baseUrl + "/equipments";
  constructor(
    private http: HttpClient
  ) { }

  getById(id: string) {
    return this.http
      .get<EquipmentModel>(this.apiBaseUrl + "/" + id)
      .pipe(map((e) => new EquipmentModel(e)));
  }

  getLists() {
    return this.http
      .get<EquipmentModel[]>(this.apiBaseUrl)
      .pipe(
        map((e) => e.map((e) => new EquipmentModel(e)))
      );
  }

  save(body: EquipmentModel) {
    return this.http.post<{
      "message": string,
      "user": EquipmentModel
    }>(this.apiBaseUrl, new EquipmentModel(body));
  }

  update(body: EquipmentModel) {
    return this.http.put<{
      "message": string,
      "user": EquipmentModel
    }>(this.apiBaseUrl + "/" + body.equipment_id, new EquipmentModel(body));
  }

  delete(body: EquipmentModel) {
    return this.http.delete<{
      "message": string,
      "user": EquipmentModel
    }>(this.apiBaseUrl + "/" + body.equipment_id);
  }


}
