import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { environment } from 'src/environments/environment';
import { map, tap, switchMap, filter, reduce } from "rxjs/operators";
import { ProjectMemberModel } from '../models/project-members';


@Injectable({
  providedIn: 'root'
})
export class ProjectMemberService {
apiBaseUrl = environment.baseUrl + "/project-members";
  constructor(
    private http: HttpClient
  ) { }

  getById(id: string) {
    return this.http
      .get<ProjectMemberModel>(this.apiBaseUrl + "/" + id)
      .pipe(map((e) => new ProjectMemberModel(e)));
  }

  getLists() {
    return this.http
      .get<ProjectMemberModel[]>(this.apiBaseUrl)
      .pipe(
        map((e) => e.map((e) => new ProjectMemberModel(e)))
      );
  }

  save(body: ProjectMemberModel) {
    return this.http.post<{
      "message": string,
      "user": ProjectMemberModel
    }>(this.apiBaseUrl, new ProjectMemberModel(body));
  }

  update(body: ProjectMemberModel) {
    return this.http.put<{
      "message": string,
      "user": ProjectMemberModel
    }>(this.apiBaseUrl + "/" + body.user_id, new ProjectMemberModel(body));
  }

  delete(body: ProjectMemberModel) {
    return this.http.delete<{
      "message": string,
      "user": ProjectMemberModel
    }>(this.apiBaseUrl + "/" + body.user_id);
  }


}
