import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { environment } from 'src/environments/environment';
import { ProJectModel } from '../models/project.model';
import { map, tap, switchMap, filter, reduce } from "rxjs/operators";

@Injectable({
  providedIn: 'root'
})
export class ProjectService {
apiBaseUrl = environment.baseUrl + "/projects";
  constructor(
    private http: HttpClient
  ) { }

  getById(id: string) {
    return this.http
      .get<ProJectModel>(this.apiBaseUrl + "/" + id)
      .pipe(map((e) => new ProJectModel(e)));
  }

  getLists() {
    return this.http
      .get<ProJectModel[]>(this.apiBaseUrl)
      .pipe(
        map((e) => e.map((e) => new ProJectModel(e)))
      );
  }

  save(body: ProJectModel) {
    return this.http.post<{
      "message": string,
      "user": ProJectModel
    }>(this.apiBaseUrl, new ProJectModel(body));
  }

  update(body: ProJectModel) {
    return this.http.put<{
      "message": string,
      "user": ProJectModel
    }>(this.apiBaseUrl + "/" + body.project_id, new ProJectModel(body));
  }

  delete(body: ProJectModel) {
    return this.http.delete<{
      "message": string,
      "user": ProJectModel
    }>(this.apiBaseUrl + "/" + body.project_id);
  }


}
